@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @author Lukas Loehrer
  * Based on ibmtts.c.
@@ -58,10 +56,11 @@
 
 #define DEBUG_MODULE 1
 DECLARE_DEBUG()
-#define DBG_WARN(e, msg)						\
+#define DBG_WARN(e, msg) do {						\
 	if (Debug && !(e)) {						\
 		DBG(DBG_MODNAME " Warning:  " msg);			\
-	}
+	} \
+} while (0)
 typedef enum {
 	FATAL_ERROR = -1,
 	OK = 0,
@@ -137,6 +136,10 @@ pthread_cond_t playback_queue_condition;
    SSIP PITCH commands then adjust relative to this. */
 static int espeak_voice_pitch_baseline = 50;
 
+/* When a voice is set, this is the baseline pitch range of the voice.
+   SSIP PITCH range commands then adjust relative to this. */
+static int espeak_voice_pitch_range_baseline = 50;
+
 /* <Function prototypes*/
 
 static void espeak_state_reset();
@@ -153,6 +156,7 @@ static int uri_callback(int type, const char *uri, const char *base);
 /* Basic parameters */
 static void espeak_set_rate(signed int rate);
 static void espeak_set_pitch(signed int pitch);
+static void espeak_set_pitch_range(signed int pitch_range);
 static void espeak_set_volume(signed int volume);
 static void espeak_set_punctuation_mode(SPDPunctuation punct_mode);
 static void espeak_set_cap_let_recogn(SPDCapitalLetters cap_mode);
@@ -192,6 +196,7 @@ MOD_OPTION_1_STR(EspeakPunctuationList)
     MOD_OPTION_1_INT(EspeakNormalRate)
     MOD_OPTION_1_INT(EspeakMaxRate)
     MOD_OPTION_1_INT(EspeakListVoiceVariants)
+    MOD_OPTION_1_INT(EspeakIndexing)
 
     MOD_OPTION_1_INT(EspeakAudioChunkSize)
     MOD_OPTION_1_INT(EspeakAudioQueueMaxSize)
@@ -218,6 +223,7 @@ int module_load(void)
 	MOD_OPTION_1_INT_REG(EspeakMaxRate, 390);
 	MOD_OPTION_1_STR_REG(EspeakPunctuationList, "@/+-_");
 	MOD_OPTION_1_INT_REG(EspeakCapitalPitchRise, 800);
+	MOD_OPTION_1_INT_REG(EspeakIndexing, 1);
 	MOD_OPTION_1_INT_REG(EspeakListVoiceVariants, 0);
 	if (EspeakCapitalPitchRise == 1 || EspeakCapitalPitchRise == 2) {
 		EspeakCapitalPitchRise = 0;
@@ -234,12 +240,6 @@ int module_init(char **status_info)
 	DBG(DBG_MODNAME " Module init().");
 	INIT_INDEX_MARKING();
 
-#ifndef GLIB_VERSION_2_32
-	/* Make sure the glib functions are thread safe. */
-	if (!g_thread_supported())
-		g_thread_init(NULL);
-#endif
-
 	*status_info = NULL;
 
 	/* Report versions. */
@@ -354,6 +354,7 @@ int module_speak(gchar * data, size_t bytes, SPDMessageType msgtype)
 	UPDATE_PARAMETER(rate, espeak_set_rate);
 	UPDATE_PARAMETER(volume, espeak_set_volume);
 	UPDATE_PARAMETER(pitch, espeak_set_pitch);
+	UPDATE_PARAMETER(pitch_range, espeak_set_pitch_range);
 	UPDATE_PARAMETER(punctuation_mode, espeak_set_punctuation_mode);
 	UPDATE_PARAMETER(cap_let_recogn, espeak_set_cap_let_recogn);
 
@@ -596,7 +597,7 @@ static void *_espeak_stop_or_pause(void *nothing)
 			module_report_event_stop();
 		}
 
-		DBG(DBG_MODNAME " Stop or pause thread ended.......\n")
+		DBG(DBG_MODNAME " Stop or pause thread ended.......\n");
 	}
 	pthread_exit(NULL);
 }
@@ -657,6 +658,32 @@ static void espeak_set_pitch(signed int pitch)
 	}
 }
 
+static void espeak_set_pitch_range(signed int pitch_range)
+{
+	assert(pitch_range >= -100 && pitch_range <= +100);
+	int pitchRangeBaseline;
+	/* Possible range 0 to 100. */
+	if (pitch_range < 0) {
+		pitchRangeBaseline =
+		    ((float)(pitch_range + 100) *
+		     espeak_voice_pitch_range_baseline) / (float)100;
+	} else {
+		pitchRangeBaseline =
+		    (((float)pitch_range *
+		      (100 - espeak_voice_pitch_range_baseline))
+		     / (float)100) + espeak_voice_pitch_range_baseline;
+	}
+	assert(pitchRangeBaseline >= 0 && pitchRangeBaseline <= 100);
+	espeak_ERROR ret =
+	    espeak_SetParameter(espeakRANGE, pitchRangeBaseline, 0);
+	if (ret != EE_OK) {
+		DBG(DBG_MODNAME " Error setting pitch range %i.",
+		    pitchRangeBaseline);
+	} else {
+		DBG(DBG_MODNAME " Pitch range set to %i.", pitchRangeBaseline);
+	}
+}
+
 static void espeak_set_punctuation_mode(SPDPunctuation punct_mode)
 {
 	espeak_PUNCT_TYPE espeak_punct_mode = espeakPUNCT_SOME;
@@ -818,6 +845,8 @@ static int synth_callback(short *wav, int numsamples, espeak_EVENT * events)
 		/* Enqueue audio upto event */
 		switch (events->type) {
 		case espeakEVENT_MARK:
+			if (!EspeakIndexing)
+				break;
 		case espeakEVENT_PLAY:{
 				/* Convert ms position to samples */
 				gint64 pos_msg = events->audio_position;
@@ -836,7 +865,8 @@ static int synth_callback(short *wav, int numsamples, espeak_EVENT * events)
 		/* Process actual event */
 		switch (events->type) {
 		case espeakEVENT_MARK:
-			espeak_add_mark_to_playback_queue(events->id.name);
+			if (EspeakIndexing)
+				espeak_add_mark_to_playback_queue(events->id.name);
 			break;
 		case espeakEVENT_PLAY:
 			espeak_add_sound_icon_to_playback_queue(events->
@@ -1194,7 +1224,7 @@ static SPDVoice **espeak_list_synthesis_voices()
 	}
 
 	numvoices = g_queue_get_length(voice_list);
-	DBG(DBG_MODNAME " %d voices total.", numvoices)
+	DBG(DBG_MODNAME " %d voices total.", numvoices);
 
 	if (EspeakListVoiceVariants) {
 		variant_spec = g_new0(espeak_VOICE, 1);
@@ -1210,7 +1240,7 @@ static SPDVoice **espeak_list_synthesis_voices()
 		}
 
 		numvariants = g_queue_get_length(variant_list);
-		DBG(DBG_MODNAME " %d variants total.", numvariants)
+		DBG(DBG_MODNAME " %d variants total.", numvariants);
 	}
 
 	totalvoices = (numvoices * numvariants) + numvoices;
