@@ -14,9 +14,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * $Id: output.c,v 1.38 2008-06-27 12:28:48 hanke Exp $
  */
@@ -31,8 +29,10 @@
 #include "output.h"
 #include "parse.h"
 
-#if !(defined(__GLIBC__) && defined(_GNU_SOURCE))
-/* Added by Willie Walker - strndup is a gcc-ism
+#ifndef HAVE_STRNDUP
+/*
+ * Added by Willie Walker - strndup was a GNU libc extension, later adopted
+ * in the POSIX.1-2008 standard, but not yet found on all systems.
  */
 char *strndup(const char *s, size_t n)
 {
@@ -52,7 +52,7 @@ char *strndup(const char *s, size_t n)
 
 	return p;
 }
-#endif /* !(defined(__GLIBC__) && defined(_GNU_SOURCE)) */
+#endif /* HAVE_STRNDUP */
 
 void output_set_speaking_monitor(TSpeechDMessage * msg, OutputModule * output)
 {
@@ -315,7 +315,7 @@ static SPDVoice **output_get_voices(OutputModule * module)
 		} else if (lines[i][3] == ' ')
 			break;
 		else if (lines[i][3] == '-') {
-			atoms = g_strsplit(&lines[i][4], " ", 0);
+			atoms = g_strsplit(&lines[i][4], "\t", 0);
 			// Name, language, dialect
 			if ((atoms[0] == NULL) || (atoms[1] == NULL)
 			    || (atoms[2] == NULL)) {
@@ -328,8 +328,7 @@ static SPDVoice **output_get_voices(OutputModule * module)
 				voice->variant = g_strdup(atoms[2]);
 				g_queue_push_tail(voices, voice);
 			}
-			if (atoms != NULL)
-				g_strfreev(atoms);
+			g_strfreev(atoms);
 		}
 		/* Should we do something in a final "else" branch? */
 
@@ -416,6 +415,8 @@ int output_send_settings(TSpeechDMessage * msg, OutputModule * output)
 	set_str = g_string_new("");
 	g_string_append_printf(set_str, "pitch=%d\n",
 			       msg->settings.msg_settings.pitch);
+	g_string_append_printf(set_str, "pitch_range=%d\n",
+			       msg->settings.msg_settings.pitch_range);
 	g_string_append_printf(set_str, "rate=%d\n",
 			       msg->settings.msg_settings.rate);
 	g_string_append_printf(set_str, "volume=%d\n",
